@@ -137,6 +137,18 @@ def is_string(value: Any) -> bool:
     return isinstance(value, str)
 
 
+def is_bytes(value: Any) -> bool:
+    """Check if the given value is a bytes or bytearray
+
+    Args:
+        value: an arbitrary value
+
+    Returns:
+        Whether or not the given value is of type bytes or bytearray
+    """
+    return isinstance(value, (bytes, bytearray))
+
+
 def get_class_that_defined_method(method: object) -> Optional[object]:
     """Retrieves the class that defines a method.
 
@@ -210,3 +222,22 @@ def wrap_var_param_type(type_: Optional[type], param_kind) -> Optional[type]:
             return typing.Dict[str, typing.Any]
         return typing.Dict[str, type_]  # type: ignore
     return type_
+
+
+def given_exception_matches(err, exc) -> bool:
+    """This is a naive approach to figure out if an exception matches, similar to
+    what CPython does here:
+    https://github.com/python/cpython/blob/ae3c66acb89a6104fcd0eea760f80a0287327cc4/Python/errors.c#L231
+
+    Args:
+        err: The raised exception
+        exc: The matching exception class
+
+    Returns:
+        True, iff the exception matches.
+    """
+    if err is None or exc is None:
+        return False
+    if not isclass(err):
+        err = type(err)
+    return issubclass(err, exc)
